@@ -330,7 +330,7 @@ def build(branch, ngBuild='', ngApp='', angularBuild='', angularEnv='', installP
 
 
 @task
-def build2(javaEnv, dirs, buildApi="True", buildWorker="True"):
+def build2(javaEnv, dirs, prodSecrets="False",buildApi="True", buildWorker="True"):
 
     # ensure maven installs all build tools
 	local("pwd")
@@ -340,12 +340,17 @@ def build2(javaEnv, dirs, buildApi="True", buildWorker="True"):
 	    local('mkdir -p deploy/api/config')
 	    local('mkdir -p deploy/api/lib')
 	 
-	    local('cp config/keyset-%s.json deploy/api/config/keyset.json' % javaEnv)
+
 	    local('cp config/logback.xml deploy/api/config/')
-	    local('cp config/application-%s.yml deploy/api/config/' % javaEnv)
+
+        if prodSecrets in TRUTH_VALUES:
+            local('aws s3 cp s3://topopps-prod-x/keyset-%s.json deploy/api/config/keyset.json' % javaEnv)
+            local('aws s3 cp s3://topopps-prod-x/application-%s.yml deploy/api/config/' % javaEnv)
+        else:
+            local('cp config/keyset-%s.json deploy/api/config/keyset.json' % javaEnv)
+    	    local('cp config/application-%s.yml deploy/api/config/' % javaEnv)
 
 	    local('cp -r api/target/lib/ deploy/api/')
-
 	    local('cp api/target/*SNAPSHOT.jar deploy/api/')
 
 
@@ -353,10 +358,18 @@ def build2(javaEnv, dirs, buildApi="True", buildWorker="True"):
 	    local('mkdir -p deploy/worker/config')
 	    local('mkdir -p deploy/worker/lib')
 
-	    local('cp config/keyset-%s.json deploy/worker/config/keyset.json' % javaEnv)
-	    local('cp config/logback.xml deploy/worker/config/')
-	    local('cp config/application-%s.yml deploy/worker/config/' % javaEnv)
-	    local('cp config/application-%s-worker.yml deploy/worker/config/' % javaEnv)
+
+        local('cp config/logback.xml deploy/worker/config/')
+        
+        if prodSecrets in TRUTH_VALUES:
+            local('aws s3 cp s3://topopps-prod-x/keyset-%s.json deploy/worker/config/keyset.json' % javaEnv)
+    	    local('aws s3 cp s3://topopps-prod-x/application-%s.yml deploy/worker/config/' % javaEnv)
+    	    local('aws s3 cp s3://topopps-prod-x/application-%s-worker.yml deploy/worker/config/' % javaEnv)
+        else:
+            local('cp config/keyset-%s.json deploy/worker/config/keyset.json' % javaEnv)
+            local('cp config/application-%s.yml deploy/worker/config/' % javaEnv)
+            local('cp config/application-%s-worker.yml deploy/worker/config/' % javaEnv)
+
 	    local('cp config/initiate_shutdown.sql deploy/worker/config/')
 	    local('cp config/finish-deploy.sh deploy/worker/config/')
 
